# SillyTavern Extension: Dynamic Chat Bubble Image Generation

## **Objective**
The goal of this extension is to dynamically generate chat bubble images containing text provided by the AI in SillyTavern. The AI will generate markdown image links that point to an API, which will return a styled chat bubble containing the text. This enables a more immersive and visually enhanced roleplay experience.

## **Functional Description**
1. **AI Markdown Output**
   - The AI will include markdown-formatted image links in its responses.
   - Example output from AI:
     ```markdown
     ![](image.php?q=Hello%20there!)
     ```
   - The `q` parameter in the URL will be dynamically filled with text.

2. **Dynamic Image Generation**
   - The provided URL (`image.php`) will be queried whenever a markdown image is rendered.
   - This PHP script will generate an image on the fly, styling the text as a chat bubble.
   - Additional parameters (e.g., `style=modern`) could be used to define different visual styles.

3. **Extension-Based Implementation**
   - The solution should be built as a **SillyTavern extension** rather than modifying the core.
   - This extension will:
     - Provide a function that AI can call via tool/function calling.
     - Process the AI's request and return a correctly formatted markdown image link.
     - Handle URL encoding of the text.

## **Implementation Strategy**
1. **Create a new SillyTavern extension**
   - Place extension files in the `extensions/` directory.
   - Define an `index.js` file that registers a tool function.
   - Include a `manifest.json` to declare the extension.

2. **Register a Tool for AI Function Calling**
   - Define a function (e.g., `generateChatBubbleImage`) that constructs the correct markdown format.
   - Ensure that the function properly encodes the text input.
   - Return a formatted markdown string (`![Chat Bubble](image.php?q=encoded_text)`).

3. **Ensure AI Utilization**
   - Modify the system prompt (if necessary) to encourage the AI to call the function.
   - Validate that the AI correctly generates responses containing image links.

## **Expected Outcome**
Once implemented, SillyTavern will be able to dynamically generate chat bubble images within the AI conversation. The extension will work independently of the core system, making it easy to maintain and update.

## **Next Steps**
- Develop the `index.js` script to register the tool.
- Ensure the extension follows SillyTavern’s extension framework.
- Test AI interactions to confirm correct markdown output.
- Refine the PHP image generator if necessary.

This document serves as the foundational plan for implementing the extension.

